@@ -147,6 +147,36 @@ def workflow_cli(gordo_ctx):
     help="retryStrategy.backoff.factor for workflow steps",
     envvar=f"{PREFIX}_RETRY_BACKOFF_FACTOR",
 )
+@click.option(
+    "--gordo-server-workers",
+    type=int,
+    help="The number of worker processes for handling Gordo server requests.",
+    envvar=f"{PREFIX}_GORDO_SERVER_WORKERS",
+)
+@click.option(
+    "--gordo-server-threads",
+    type=int,
+    help="The number of worker threads for handling requests.",
+    envvar=f"{PREFIX}_GORDO_SERVER_THREADS",
+)
+@click.option(
+    "--gordo-server-probe-timeout",
+    type=int,
+    help="timeoutSeconds value for livenessProbe and readinessProbe of Gordo server Deployment",
+    envvar=f"{PREFIX}_GORDO_SERVER_PROBE_TIMEOUT",
+)
+@click.option(
+    "--without-prometheus",
+    is_flag=True,
+    help="Do not deploy Prometheus for Gordo servers monitoring",
+    envvar=f"{PREFIX}_WITHOUT_PROMETHEUS",
+)
+@click.option(
+    "--prometheus-metrics-server-workers",
+    help="Number of workers for Prometheus metrics servers",
+    envvar=f"{PREFIX}_PROMETHEUS_METRICS_SERVER_WORKERS",
+    default=1,
+)
 @click.pass_context
 def workflow_generator_cli(gordo_ctx, **ctx):
     """
@@ -185,6 +215,9 @@ def workflow_generator_cli(gordo_ctx, **ctx):
     context["model_builder_resources_limits_cpu"] = builder_resources["limits"]["cpu"]
 
     context["server_resources"] = config.globals["runtime"]["server"]["resources"]
+    context["prometheus_metrics_server_resources"] = config.globals["runtime"][
+        "prometheus_metrics_server"
+    ]["resources"]
 
     # These are also set in the default globals, and guaranteed to exist
     client_resources = config.globals["runtime"]["client"]["resources"]
